@@ -27,6 +27,7 @@ from urllib.parse import urlparse
 from gql import Client as GraphQLClient
 from gql import gql
 from gql.transport.aiohttp import AIOHTTPTransport
+from gql.transport.exceptions import TransportQueryError
 from graphql import DocumentNode, ExecutionResult
 
 from .client import (
@@ -49,6 +50,7 @@ from .client import (
     UpdateManagedSchemaParams,
     UpdateManagedSchemaResponse,
 )
+from .errors import is_upload_in_progress_error
 
 
 @dataclass(frozen=True)
@@ -129,7 +131,16 @@ class PublicAPIClient(Client):
         query = self._requests.bulk_upload_mutation()
         upload_params = {"input": {"data": params.encoded_bytes()}}
         default_stats = dict(total=0, new=0, modified=0)
-        res = self._execute(query, variable_values=upload_params)
+        try:
+            res = self._execute(query, variable_values=upload_params)
+        except TransportQueryError as e:  # pylint: disable=C0103
+            err = BackendError(e)
+            err.permanent = True
+            if e.errors and len(e.errors) > 0:
+                err = BackendError(e.errors)
+                if is_upload_in_progress_error(e.errors[0]):
+                    err.permanent = False
+            raise err from e
 
         if res.errors:
             raise BackendError(res.errors)
@@ -299,6 +310,7 @@ class PublicAPIClient(Client):
         rule_upload_stats = res.data.get("uploadDetectionEntities", {}).get("rules", {})
         policy_upload_stats = res.data.get("uploadDetectionEntities", {}).get("policies", {})
         query_upload_stats = res.data.get("uploadDetectionEntities", {}).get("queries", {})
+        data_models_upload_stats = res.data.get("uploadDetectionEntities", {}).get("dataModels", {})
         return BackendResponse(
             status_code=200,
             data=PantherSDKBulkUploadResponse(
@@ -317,6 +329,11 @@ class PublicAPIClient(Client):
                     new=query_upload_stats.get("new"),
                     total=query_upload_stats.get("total"),
                 ),
+                data_models=BulkUploadStatistics(
+                    modified=data_models_upload_stats.get("modified"),
+                    new=data_models_upload_stats.get("new"),
+                    total=data_models_upload_stats.get("total"),
+                ),
             ),
         )
 
